# Hydra Range Sweeper plugin

This hydra plugin provides a range sweeper that lets you specify an integer range with the syntax

```
python example.py foo=1:7:2 bar=1:4
```

# Installation and usage

Install using `pip install hydra-range-sweeper-badr`
Then specify `hydra/sweeper=range` in your app config